;; Generated package description from tempel.el  -*- no-byte-compile: t -*-
(define-package "tempel" "1.0" "Tempo templates/snippets with in-buffer field editing" '((emacs "27.1") (compat "29.1.4.0")) :commit "38dad1f85104c7c734ad9245f3a85b49562332d0" :authors '(("Daniel Mendler" . "mail@daniel-mendler.de")) :maintainer '("Daniel Mendler" . "mail@daniel-mendler.de") :keywords '("abbrev" "languages" "tools" "wp") :url "https://github.com/minad/tempel")
